@@ -54,13 +54,16 @@ typedef enum
     /* bit0 is the "verbose" bit -- the __debug_enabled macro relies on this */
     /* cov library related features */
     D_FILES=1,
+    D_CPP,
     D_BB,
     D_BBG,
     D_DA,
     D_CGRAPH,
     D_SOLVE,
     D_STABS,
+    D_DWARF,
     D_DUMP,
+    D_REPORT,
     /* gui related features */
     D_UICORE,
     D_SUMMARYWIN,
@@ -71,6 +74,7 @@ typedef enum
     D_FILESWIN,
     D_GRAPHWIN,
     D_GRAPH2WIN,
+    D_REPORTWIN,
     /* bitwise OR in D_VERBOSE to enable printing only when verbose */
 #define _D_VERBOSE_SHIFT    7
     D_VERBOSE=(1<<_D_VERBOSE_SHIFT)
