@@ -23,7 +23,7 @@
 #include "string_var.H"
 #include "tok.H"
 
-CVSID("$Id: ui.c,v 1.21.2.2 2003/11/04 12:55:08 gnb Exp $");
+CVSID("$Id: ui.c,v 1.22 2003/11/03 23:02:50 gnb Exp $");
 
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
@@ -643,7 +643,7 @@ ui_tree_view_double_click_data(GtkTreeView *tv, GdkEvent *event, int column)
     	if (debug_enabled(D_UICORE))
 	{
     	    string_var path_str = gtk_tree_path_to_string(path);
-    	    dprintf1(D_UICORE, "ui_tree_view_double_click_data: path=\"%s\"\n",
+    	    duprintf1("ui_tree_view_double_click_data: path=\"%s\"\n",
 	    	    	    path_str.data());
     	}
     	model = gtk_tree_view_get_model(tv);
